@@ -9,8 +9,8 @@
 #' @export
 #' @usage gbif_issues()
 #' @source
-#'   <http://gbif.github.io/gbif-api/apidocs/org/gbif/api/vocabulary/OccurrenceIssue.html>,
-#'   <https://gbif.github.io/gbif-api/apidocs/org/gbif/api/vocabulary/NameUsageIssue.html>
+#' https://gbif.github.io/gbif-api/apidocs/org/gbif/api/vocabulary/OccurrenceIssue.html
+#' https://gbif.github.io/gbif-api/apidocs/org/gbif/api/vocabulary/NameUsageIssue.html
 #'
 gbif_issues <- function() gbifissues
 
@@ -23,6 +23,7 @@ gbifissues <- structure(list(
            "preneglon", "preswcd", "rdativ", "rdatm", "rdatunl", "refuriiv",
            "txmatfuz", "txmathi", "txmatnon", "typstativ", "zerocd",
            "cdpi", "cdumi", "indci", "interr", "iccos", "osiic", "osu",
+           "geodi","geodu",
            "anm", "annu", "anuidi", "aitidinv", "bbmn", "basauthm",
            "bibrinv", "chsun", "clasna", "clasroi", "conbascomb", "desinv",
            "disinv", "hom", "minv", "npm", "ns","nsinv", "onder", "onnu",
@@ -47,6 +48,7 @@ gbifissues <- structure(list(
             "COORDINATE_PRECISION_INVALID", "COORDINATE_UNCERTAINTY_METERS_INVALID",
             "INDIVIDUAL_COUNT_INVALID", "INTERPRETATION_ERROR",
             "INDIVIDUAL_COUNT_CONFLICTS_WITH_OCCURRENCE_STATUS", "OCCURRENCE_STATUS_INFERRED_FROM_INDIVIDUAL_COUNT", "OCCURRENCE_STATUS_UNPARSABLE",
+            "GEOREFERENCED_DATE_INVALID","GEOREFERENCED_DATE_UNLIKELY",
             "ACCEPTED_NAME_MISSING", "ACCEPTED_NAME_NOT_UNIQUE", "ACCEPTED_NAME_USAGE_ID_INVALID",
             "ALT_IDENTIFIER_INVALID", "BACKBONE_MATCH_NONE",
             "BASIONYM_AUTHOR_MISMATCH", "BIB_REFERENCE_INVALID", "CHAINED_SYNOYM",
@@ -100,6 +102,8 @@ gbifissues <- structure(list(
                   "Example: individual count value > 0, but occurrence status is absent and etc.",
                   "Occurrence status was inferred from the individual count value",
                   "Occurrence status value can't be assigned to OccurrenceStatus",
+                  "The date given for dwc:georeferencedDate is invalid and can't be interpreted at all.",
+                  "The date given for dwc:georeferencedDate is in the future or before Linnean times (1700).",
                   "Synonym lacking an accepted name.",
                   "Synonym has a verbatim accepted name which is not unique and refers to several records.",
                   "The value for dwc:acceptedNameUsageID could not be resolved.",
@@ -135,8 +139,8 @@ gbifissues <- structure(list(
                   "no description",
                   "The scientific name string could not be parsed at all, but appears to be a parsable name type, i.e.",
                   "At least one vernacular name extension record attached to this name usage is invalid."),
-  type <- c(rep("occurrence", 49), rep("name", 35)
-  )), .Names = c("code", "issue", "description", "type"), class = "data.frame", row.names = c(NA, -84L))
+  type <- c(rep("occurrence", 51), rep("name", 35)
+  )), .Names = c("code", "issue", "description", "type"), class = "data.frame", row.names = c(NA, -86L))
 
 collapse_issues <- function(x, issue_col = "issues") {
   tmp <- x[names(x) %in% issue_col][[1]]
